@@ -17,10 +17,26 @@
 #' points(cania.sub.ts$Date, bf, type="l", col="blue")
 
 bf_eckhardt <- function(discharge, a, BFI){
-    bf <- rep(discharge[1],length(discharge))
-    for(i in 2:length(discharge)) {
-        bf[i] <-(((1 - BFI)* a* bf[i-1]) + ((1-a)* BFI* discharge [i])) /(1- a*BFI)
-        if(bf[i] > discharge[i]) bf[i] <- discharge[i]
+    
+    # Remove NA values and store the indices
+    na_indices <- is.na(discharge)
+    discharge_sub <- discharge[!na_indices]
+    
+    # Pre-allocate the output vector
+    bf <- numeric(length(discharge_sub))
+    
+    # Initialize the first value
+    bf[1] <- discharge_sub[1]
+    
+    # Calculate the base flow using vectorized operations
+    for (i in 2:length(discharge_sub)) {
+        bf[i] <- (((1 - BFI) * a * bf[i-1]) + ((1 - a) * BFI * discharge_sub[i])) / (1 - a * BFI)
+        if (bf[i] > discharge_sub[i]) bf[i] <- discharge_sub[i]
     }
-    return(bf)
+    
+    # Create the final output vector with NAs in the original positions
+    bf_out <- rep(NA, length(discharge))
+    bf_out[!na_indices] <- bf
+    
+    return(bf_out)
 }
\ No newline at end of file
