@@ -1,4 +1,4 @@
-#' Create a screening plot
+#' Create a summary screening plot
 #'
 #' Produces summary screening plots of high flow, low flow, or baseflow metrics.  
 #' Each plot shows significant temporal trends and step changes. Intended for use as 
@@ -10,11 +10,6 @@
 #'   metrics.
 #' @param language Language for plot labels.  Choice of either "English" or
 #'   "French". Default is "English".
-#' @param StnInfo Optional data.frame containing user-supplied station info for plot. 
-#'   data.frame must have 7 columns containing station info in the following order:
-#'   Station ID, Station Name, Prov/State, Country, Latitude, Longitude, Catchment Area
-#'   If any of the information is unavailabe, fill with NA.  The Station ID column must
-#'   match the Station ID in column 1 of the data.frame input from \code{\link{create.ts}}.
 #' @details For the center of volume (COV) plots on the high flow and baseflow screening plots,
 #'   the correlation coefficients for COV and years and for
 #'   mean annual flow (MAF) and years are added to the plot. The ratio of the correlation coefficients 
@@ -31,17 +26,42 @@
 #' @references Whitfield, P.H. 2013. Is 'Center of Volume' a robust indicator of changes 
 #'   in snowmelt timing? Hydrological Processes 27:2691-8.
 #' @author Jennifer Dierauer
+#' @importFrom grDevices heat.colors
+#' @import graphics
 #' @export
 #' @examples
 #' # load results from metrics.all function for the Caniapiscau River
 #' data(caniapiscau.res)
 #' 
 #' # create a summary flow screening plot of the high flow metrics
-#' screen.summary(caniapiscau.res, type="l")
+#' screen.summary(caniapiscau.res, type="h")
+#' # screen.summary(caniapiscau.res, type = "l")
+#' # screen.summary(caniapiscau.res, type = "b)
 
 
-screen.summary <- function(metrics, type="h", language="English", StnInfo=NULL) {
+screen.summary <- function(metrics, type="h", language="English") {
+  
+  if (!(is.list(metrics))) {
+    if ((length(metrics) == 1)) {
+      if (metrics == "Flow screening not completed. Streamflow record must contain at least 10 hydrologic years of data.") {
+        message(metrics)
+      } else {stop("Invalid Input")}
+    } else {stop("Invalid Input")}
+  }
     
+  if (!("metricTS" %in% names(metrics))) {
+    stop("Invalid Input")
+  }  
+  if (!("tcpRes" %in% names(metrics))) {
+    stop("Invalid Input")
+  }
+  if (!("indata" %in% names(metrics))) {
+    stop("Invalid Input")
+  }
+  if (!("OmitYrs" %in% names(metrics))) {
+    stop("Invalid Input")
+  }
+  
     opar <- graphics::par(no.readonly = TRUE)
     
     TS <- metrics[[3]]
@@ -73,27 +93,21 @@ screen.summary <- function(metrics, type="h", language="English", StnInfo=NULL)
         Qmax <- paste("0.", Qmax, sep="")
     }
     
-    MyXlabs <- get.titles.internal(type, language, Qmax)$Xlabs
-    MyYlabs <- get.titles.internal(type, language, Qmax)$Ylabs
+    MyXlabs <- get.titles.internal(type, TS$FlowUnits[1], language, Qmax)$Xlabs
+    MyYlabs <- get.titles.internal(type, TS$FlowUnits[1], language, Qmax)$Ylabs
 
     ###layout map sheet
     graphics::layout(matrix(c(1,2,3,3,4,5,3,3,6,7,8,9,10,11,12,13),4,4,byrow=TRUE))
     graphics::par(oma=c(0,0,3,0))
-    
-    # check formatting of input StnInfo, if StnInfo is not NULL
-    if (!is.null(StnInfo)) {
-        StnInfo[,1] <- as.character(StnInfo[,1])
-        StnInfo[,2] <- as.character(StnInfo[,2])
-        StnInfo[,3] <- as.character(StnInfo[,3])
-        StnInfo[,4] <- as.character(StnInfo[,4])
-        StnInfo[,5] <- as.numeric(StnInfo[,5])
-        StnInfo[,6] <- as.numeric(StnInfo[,6])
-        StnInfo[,7] <- as.numeric(StnInfo[,7])
-    }
 
     ### Panel 1 - Station Info Text #####
-    StnInfo <- station.info(TS, StnInfo, Plot=T, language)
-    Country <- StnInfo$Country
+    if (!is.na(TS$Agency[1])) {
+      StnInfo <- station.info(TS$Agency[1], TS$ID[1], Plot=T, language)
+      Country <- StnInfo$Country
+    } else {
+      StnInfo <- station.info("Unknown", TS$ID[1], Plot=T, language)
+      Country <- NA
+    }
 
     ### Plot 2 - flow regime summary plot
     regime.internal(TS)
@@ -129,7 +143,7 @@ screen.summary <- function(metrics, type="h", language="English", StnInfo=NULL)
         mYlims <- c(0, 1.2*max(TS$Flow))
         graphics::plot(TS$Date, TS$Flow,
              pch=19, col=SYMcol[codes], cex=0.5,
-             xlab="", ylab="", ylim=mYlims)
+             xlab="", ylab="", ylim=mYlims, las = 1)
         graphics::title(ylab=MyYlabs[3], line=2)
         graphics::legend(TS$Date[1], 1.15*max(TS$Flow), SYMnames, pch=19, pt.cex=0.9, cex=0.9, col=SYMcol,
                bty="n", xjust=0, x.intersp=0.5, yjust=0.5, ncol=3)
@@ -140,13 +154,13 @@ screen.summary <- function(metrics, type="h", language="English", StnInfo=NULL)
         mYlims <- c(0, 1.2*max(TS$Flow))
         graphics::plot(TS$Date, TS$Flow,
              pch=19, cex=0.5,
-             xlab="", ylab="", ylim=mYlims)
+             xlab="", ylab="", ylim=mYlims, las = 1)
         graphics::title(ylab=MyYlabs[3], line=2)
         
     }
 
     ### add shaded polygons covering missing data periods
-    MissingDays <- NA.runs(TS)
+    MissingDays <- NA.runs(TS, quiet=TRUE)
     polycol <- grDevices::heat.colors(1, alpha=0.2)
     if (length(MissingDays$Start) != 0) {
         for (i in 1:length(MissingDays$Start)) {
@@ -158,9 +172,8 @@ screen.summary <- function(metrics, type="h", language="English", StnInfo=NULL)
     }
         
     omityrs <- metrics[[4]]$Years
-    Year1 <- min(c(as.numeric(TS$hyear[1]), as.numeric(TS$year[1])))
-    YearEnd <- max(c(max(as.numeric(TS$year[!(TS$year %in% omityrs)])), 
-                     max(as.numeric(TS$hyear[!(TS$hyear %in% omityrs)]))))
+    Year1 <- min(as.numeric(TS$hyear))
+    YearEnd <- max(as.numeric(TS$hyear))
     hyrstart <- as.numeric(subset(TS, TS$hmonth == 1)$month[1])
     
     ## Plots 4 to 13
@@ -170,7 +183,8 @@ screen.summary <- function(metrics, type="h", language="English", StnInfo=NULL)
           screen.summary.internal(inmetrics[[i]], inparams[[i]], type, 
                                      MyYlabs, i, DataType, maf, Year1, YearEnd, hyrstart)
       } else {
-        graphics::plot(c(1:10), c(1:10), col="white", ylab="", xlab="", yaxt="n", xaxt="n")
+        graphics::plot(c(1:10), c(1:10), col="white", ylab="", 
+                       xlab="", yaxt="n", xaxt="n", las = 1)
         graphics::text(1, 5, inparams[[i]][[2]], adj=c(0, 0))
         graphics::text(x = 1, y = 3, "NA", adj=c(0, 0))
       }
